==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-session/lxqt-config-session/lxqt-config-session_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Keisti</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Laukti sistemos dėklo</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Pasirinkite programą</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Nuo aplinkos nepriklausomas programų paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>LXQt automatinis programų paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Vieta: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Nustelbia: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Keisti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Automatinis programų paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Failas „%1“ jau yra!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Langų tvarkyklė</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Pagrindinės nuostatos</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>Pasirinkite langų tvarkyklę</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Pasirinkite terminalo emuliatorių</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Pasirinkite saityno naršyklę</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Numatytosios programos</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminalo emuliatorius:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Saityno naršyklė:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Šalinti</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Aplinkos kintamieji (sudėtingiau)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Kintamasis</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Reikšmė</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LXQt Session Configuration</source>
        <translation type="vanished">LXQt sesijų konfigūravimas</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Pagrindinės nuostatos</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Numatytosios programos</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Automatinis paleidimas</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Aplinka (sudėtingiau)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Reikia iš naujo paleisti sesiją</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Tam, kad įsigaliotų pakeitimai, iš naujo paleiskite darbalaukio sesiją (lxqt-session). Atsijungti galite naudodamiesi pagrindiniu meniu.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-session/lxqt-config-session/lxqt-config-session_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Pavadinimas:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Komanda:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Laukti sistemos dėklo</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Pasirinkite programą</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>Visuotinis automatinis paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>LXQt automatinis paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>Vieta: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>Nustelbia: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Taisyti</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Automatinis programų paleidimas</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Failas &quot;%1&quot; jau yra!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Pagrindiniai nustatymai</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Langų tvarkytuvė</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt moduliai</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Paleisti</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Stabdyti</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Išėjimas iš seanso</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Išeinant iš seanso, klausti patvirtinimo</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Užrakinti ekraną prieš pristabdant/užmigdant</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="146"/>
        <source>Select a window manager</source>
        <translation>Pasirinkite langų tvarkytuvę</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Pasirinkite terminalo emuliatorių</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Pasirinkite saityno naršyklę</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Numatytosios programos</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Terminalo emuliatorius:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Ieškoti...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Saityno naršyklė:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Pridėti</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Aplinkos kintamieji (Išplėstiniai)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Kintamojo pavadinimas</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Reikšmė</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>Vykdoma</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt seanso nustatymai</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Pagrindiniai nustatymai</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Numatytosios programos</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation>Naudotojo katalogai</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Automatinis paleidimas</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Aplinka (Išplėstiniai)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>Reikalingas seanso paleidimas iš naujo</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Kai kurie nustatymai neįsigalios tol, kol neprisijungsite iš naujo.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation>Asmeninių failų vietos</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt seanso nustatymai - Naudotojo katalogai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Taikant nustatymus, skirtus vietai %1, įvyko klaida</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation>Pasirinkite vietą</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation>Darbalaukis</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation>Atsiuntimai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation>Šablonai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation>Viešiniai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation>Dokumentai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation>Paveikslai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation>Vaizdo įrašai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Talpina visus failus, kuriuos matote savo darbalaukyje</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Numatytasis aplankas į kurį yra įrašomi visi jūsų atsisiųsti failai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Numatytasis aplankas iš kurio yra įkeliami ar į kurį yra įrašomi šablonai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation>Numatytasis aplankas, skirtas jūsų failų viešam bendrinimui</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Numatytasis aplankas iš kurio yra įkeliami ar į kurį yra įrašomi dokumentai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation>Numatytasis aplankas iš kurio yra įkeliama ar į kurį yra įrašoma muzika</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Numatytasis aplankas iš kurio yra įkeliami ar į kurį yra įrašomi paveikslai</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Numatytasis aplankas iš kurio yra įkeliami ar į kurį yra įrašomi vaizdo įrašai</translation>
    </message>
</context>
</TS>
